<?php
namespace KERN23\K23Imagecrop\Controller;


/***************************************************************
 *  Copyright notice
 *
 *  (c) 1999-2013 Hendrik Reimers <kontakt@kern23.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Script Class for the crop form
 *
 * @author Hendrik Reimers <kontakt@kern23.de>
 */
class CropController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {
	
	/*
	 * Path to the Extension directory
	 *
	 * @var \string
	 */
	private $extPath;
	
	/*
	 * Initializes the controller
	 *
	 * @return void
	 */
	public function initializeAction() {
		// We need the Path
		$this->extPath = \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::siteRelPath($this->request->getControllerExtensionKey());
	}
	
	/*
	 * Shows the cropping wizard
	 *
	 * @return void
	 */
	public function wizardAction() {		
		// Get the TypoScript settings from the TS Template
		#$this->settings['presets'] = \KERN23\K23Imagecrop\Utility\Helper::mergeTsPresets($this->settings['presets']);
		
		// Get the filename
		$fileName = $this->request->getArgument('file');
		
		// Get image info
		$imgInfo = \KERN23\K23Imagecrop\Utility\Image::getImageInfo(
			$fileName,
			$this->settings['image']['view']['maxW'],
			$this->settings['image']['view']['maxH']
		);
		
		// Get preview image info
		$preInfo = \KERN23\K23Imagecrop\Utility\Image::getImageInfo(
			$fileName,
			$this->settings['image']['preview']['maxW'],
			$this->settings['image']['preview']['maxH']
		);
		
		// Get relation scale of the presets
		if ( count($this->settings['presets']) > 0 ) {
			foreach ( $this->settings['presets'] as $key => $preset ) {
				// Scale for selection
				$presetScale = \KERN23\K23Imagecrop\Utility\Image::getScale(
					$preset['width'],
					$preset['height'],
					$this->settings['image']['view']['maxW'],
					$this->settings['image']['view']['maxH']
				);
				
				// Add scale
				$presets[$key] = array_merge($preset,$presetScale);
				
				// Scale of the preview window
				$presetScale = \KERN23\K23Imagecrop\Utility\Image::getScale(
					$preset['width'],
					$preset['height'],
					$this->settings['image']['preview']['maxW'],
					$this->settings['image']['preview']['maxH']
				);
				
				// add scale
				$presets[$key]['scaledWidthPreview'] = $presetScale['scaledWidth'];
				$presets[$key]['scaledHeightPreview'] = $presetScale['scaledHeight'];
			}
		}
		
		// Put it into the template
		$this->view->assign('image',$imgInfo);
		$this->view->assign('preview',$preInfo);
		$this->view->assign('presets',$presets);
		$this->view->assign('referer',$_SERVER['HTTP_REFERER']);
	}
	
	/*
	 * Crop and saves the new Image
	 *
	 * @return void
	 */
	public function saveAction() {
		// Get the TypoScript settings from the TS Template
		#$this->settings['presets'] = \KERN23\K23Imagecrop\Utility\Helper::mergeTsPresets($this->settings['presets']);
		$srcFile = $this->request->getArgument('srcFile');
		
		$width   = ceil(($this->request->getArgument('w') / $this->request->getArgument('scaledPercent')) * 100);
		$height  = ceil(($this->request->getArgument('h') / $this->request->getArgument('scaledPercent')) * 100);
		$x       = ceil(($this->request->getArgument('x1') / $this->request->getArgument('scaledPercent')) * 100);
		$y       = ceil(($this->request->getArgument('y1') / $this->request->getArgument('scaledPercent')) * 100);
		
		$preset  = $this->request->getArgument('preset');
		$resize  = ( ($preset > -1) && ($this->settings['presets'][$preset]['resize'] == 1) ) ? true : false;
		$resW    = ( $preset > -1 ) ? intval($this->settings['presets'][$preset]['width']) : 0;
		$resH    = ( $preset > -1 ) ? intval($this->settings['presets'][$preset]['height']) : 0;
		
		$dstFile = dirname($srcFile).'/'.$this->request->getArgument('newFilename');
		
		\KERN23\K23Imagecrop\Utility\Image::cropImage(
			$srcFile,
			$dstFile,
			$x,
			$y,
			$width,
			$height,
			$resize,
			$resW,
			$resH
		);
		
		if ( ($this->settings['presets'][$preset]['composite'] == 1) && (@file_exists(PATH_site.$this->settings['presets'][$preset]['overlay'])) ) {
			\KERN23\K23Imagecrop\Utility\Image::compositeImage(
				$dstFile,
				PATH_site.$this->settings['presets'][$preset]['overlay'],
				$dstFile
			);
		}
		
		header("Location: ".$this->request->getArgument('referer'));
	}
	
}

?>