<?php

namespace KERN23\K23Imagecrop\Utility;

class Image {
	
	/**
	 * Gets all Information of an Image
	 *
	 * @param string $fileName
	 * @param string $maxW
	 * @param string $maxH
	 *
	 * @return array Image Data
	 */
	public static function getImageInfo($fileName,$maxW,$maxH) {
		$addPath     = '../../../../fileadmin/';
		$file        = $addPath.$fileName;
		
		$imgInfo  = \KERN23\K23Imagecrop\Utility\Image::getImageDimensions($file);
		$imgScale = \KERN23\K23Imagecrop\Utility\Image::getImageScale($file,array(
			"maxW" => $maxW,
			"maxH" => $maxH
		));
		
		$imgInfo['scaledWidth']   = $imgScale[0];
		$imgInfo['scaledHeight']  = $imgScale[1];
		$imgInfo['scaledPercent'] = ceil((100 / $imgInfo['width']) * $imgInfo['scaledWidth']);
		
		return $imgInfo;
	}
	
	/**
	 * Gets basic Information of an Image
	 *
	 * @param string $imgFile
	 *
	 * @return array Image Info
	 */
	public static function getImageDimensions($imgFile) {
		$gf      = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Core\\Imaging\\GraphicalFunctions');
		
		list($imgInfo['width'],$imgInfo['height'],$imgInfo['ext'],$imgInfo['fileName']) = $gf->getImageDimensions($imgFile);
		
		return $imgInfo;
	}
	
	/**
	 * Adds scaling informations of an Image
	 *
	 * @param string $imgFile
	 * @param array $options
	 *
	 * @return array
	 */
	public static function getImageScale($imgFile,$options) {
		$gf          = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Core\\Imaging\\GraphicalFunctions');
		$origImgInfo = $gf->getImageDimensions($imgFile);
		
		return $gf->getImageScale($origImgInfo,$origImgInfo[0],$origImgInfo[1],$options);
	}
	
	/**
	 * Gets scale info without a image file
	 *
	 * @param string $origWidth
	 * @param string $origHeight
	 * @param string $maxWidth
	 * @param string $maxHeight
	 *
	 * @return array
	 */
	public static function getScale($origWidth,$origHeight,$maxWidth,$maxHeight) {
		$origImgInfo[0] = $origWidth;
		$origImgInfo[1] = $origHeight;
		
		$options = array(
			"maxW" => &$maxWidth,
			"maxH" => &$maxHeight
		);
		
		$gf        = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Core\\Imaging\\GraphicalFunctions');
		$scaleInfo = $gf->getImageScale($origImgInfo,$origImgInfo[0],$origImgInfo[1],$options);
		
		$imgInfo['width']         = $origWidth;
		$imgInfo['height']        = $origHeight;
		$imgInfo['scaledWidth']   = $scaleInfo[0];
		$imgInfo['scaledHeight']  = $scaleInfo[1];
		$imgInfo['scaledPercent'] = ceil((100 / $imgInfo['width']) * $imgInfo['scaledWidth']);
		
		return $imgInfo;
	}
	
	/**
	 * Gets scale info without a image file
	 *
	 * @param string $srcFile
	 * @param string $dstFile
	 * @param int $x
	 * @param int $y
	 * @param int $width
	 * @param int $height
	 * @param bool $resize
	 * @param int $resWidth
	 * @param int $resHeight
	 *
	 * @return bool
	 */
	public static function cropImage($srcFile,$dstFile,$x,$y,$width,$height,$resize = FALSE,$resWidth = 0, $resHeight = 0) {
		self::magickCheck();
		
		#$addPath = PATH_site.'fileadmin/';
		$addPath = '';
		$srcFile = $addPath.$srcFile;
		$dstFile = $addPath.$dstFile;
		
		$image = new \Imagick($srcFile);
		$image->setCompressionQuality(100);
		$image->cropImage($width,$height,$x,$y);
		
		if ( $resize === TRUE ) $image->thumbnailImage($resWidth,$resHeight);
		
		if ( $image->writeImage($dstFile) ) {
			return true;
		} else return false;
	}
	
	/**
	 * Combines two images
	 *
	 * @param string $imgFile
	 * @param string $overlayImgFile
	 * @param string $dstFile
	 *
	 * @return bool
	 */
	public static function compositeImage($imgFile,$overlayImgFile,$dstFile) {
		self::magickCheck();
		
		#$addPath        = PATH_site.'fileadmin/';
		$addPath        = '';
		$imgFile        = $addPath.$imgFile;
		$overlayImgFile = $addPath.$overlayImgFile;
		$dstFile        = $addPath.$dstFile;
		
		$img1 = new \Imagick($imgFile);
		$img2 = new \Imagick($overlayImgFile);
		
		$img1->setCompressionQuality(100);
		$img1->setImageColorspace($img2->getImageColorspace()); 
		$img1->compositeImage($img2, $img2->getImageCompose(), 0, 0);
				
		if ( $img1->writeImage($dstFile) ) {
			return true;
		} else return false;
	}
	
	/**
	 * Check for magick
	 *
	 * @return void
	 */
	private static function magickCheck() {
		// Let's check whether we can perform the magick.
		if (TRUE !== extension_loaded('imagick')) {
			throw new Exception('Imagick extension is not loaded.');
		}
		
		// This check is an alternative to the previous one.
		// Use the one that suits you better.
		if (TRUE !== class_exists('\Imagick')) {
			throw new Exception('Imagick class does not exist.');
		} 
	}
	
}

?>